@@ -73,7 +73,7 @@ def plot_importance(booster, features = {}, width = 0.6, xrange = None, yrange =
 
     if isinstance(features, list):
         features = {
-            f"F{f}": features[f] for f in range(len(features))
+            f"f{f}": features[f] for f in range(len(features))
         }
 
     tuples = [(k, importance[k]) for k in importance]
@@ -84,6 +84,8 @@ def plot_importance(booster, features = {}, width = 0.6, xrange = None, yrange =
         tuples = sorted(tuples, key=lambda x: x[1])
     labels, values = zip(*tuples)
 
+    print(features)
+    print([features.get(label, label.upper()) for label in labels])
     text = [xlabel + ": " + str(value) for value in values]
     fig = go.Figure(go.Bar(
             y = [features.get(label, label.upper()) for label in labels],
